@@ -4,7 +4,7 @@
 
 // use anyhow::{Result};
 use sets::{Set,OrderedSet,IndexedSet,RankedSet,SetOps};
-use indxvec::{Indices,merge::*};
+use indxvec::{wi,wt,Indices,merge::*};
 
 #[test]
 fn conversions() -> () { 
@@ -25,22 +25,19 @@ fn conversions() -> () {
 }
 
 #[test]
-fn setops() -> () { 
+fn settest() -> () { 
    let v = vec![1.,14.,2.,13.,3.,12.,4.,11.,5.,10.,10.,6.,9.,7.,8.,16.];   
-   let setv = Set::from_slice(&v);  
-   println!("{}",setv); // Display of Set 
+   let setv = OrderedSet::from_slice(&v,false);  
+   println!("{}",setv); // Display of Set
+   println!("Reverse-> {}",setv.reverse()); 
    println!("Nonrepeat-> {}",setv.nonrepeat()); // Display of Set    
-   println!("Is {} member? {}",0.0, setv.member(0.0));  
-   println!("Infsup: {:?}",setv.infsup());
-   let setw = Set::from_slice(&[20.,19.,18.,17.,16.,15.]);
+   println!("Is {} a member? {}\n",wi(&0.0),wi(&setv.member(0.0))); 
+   println!("Infsup: {}",wt(&setv.infsup()));
+   let setw = OrderedSet::from_slice(&[20.,19.,18.,17.,16.,15.],true);
    println!("{}",setw);
    let us = setw.union(&setv);
    println!("Union-> {}",&us);
    println!("Intersection-> {}",setw.intersection(&setv));
    println!("Difference-> {}",setw.difference(&setv));
-   // let oset = OrderedSet::from_slice(&v,true);
-   // let ixset = IndexedSet::from_set(&setv,false);  
-   // let rxset = RankedSet::from_slice(&v,false);
-
    ()
 }
\ No newline at end of file
